<?php
/**
 * classes/ibit_Action_EvaluationEditTemplate.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright IBIT 2006-2008
 * @version 2.0.15
 */

/**
 * Diese Klasse stellt die Funktionalitt zum Bearbeiten und Erstellen einer Evaluationsvorlage dar.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Ivn Marcos <ivan.marcos@gmx.net>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    2.0.5
 */

class ibit_Action_EvaluationEditTemplate
{
	/**
	 * Referenz auf das aufrufende Objekt
	 * @var object $parent
	 */
	var $parent;

	/**
	 * Id der Evaluationsvorlage
	 * @var int $template_id
	 */
	var $template_id = null;

	/**
	 * Enthlt das Evaluationsvorlagenobjekt
	 * @var object $template
	 */
	var $template;

	/**
	 * Der Konstruktor der Klasse
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param int $template_id Id der Evaluationsvorlage
	 */
 	function ibit_Action_EvaluationEditTemplate( $parent, $template_id = null )
 	{
 		$this->parent = $parent;

		if ( !empty( $template_id ) )
		{
			$this->template_id = $template_id;
			$this->load( $template_id );
		}
	}

	/**
	 * Zeigt die Evaluationsvorlagen-Bearbeitungsoberflche an.
	 * Ldt dabei die Evaluationsvorlage aus der Session oder erstellt eine neue, falls in der Session keine vorhanden ist.
	 */
	function display()
	{
		# Vorlage in der Session vorhanden
		if ( isset( $_SESSION['template'] ) )
		{
			$template = unserialize($_SESSION['template']);
			# Abbrechen, falls, falsches Format
			if (!is_array($template))
			{
				print 'ERROR : !is_array()';
				return;
			}
		}
		# Neue Vorlage erstellen
		else
		{
			$template = array( );
			$template['title'] = '';
			$template['description'] = '';
			$template['status'] = 0;
			$template['groups'] = array();

			$_SESSION['template'] = serialize($template);
		}

		# Links erstellen
		$links = array(
			'base' => $this->parent->base_link,
			'menu' => $this->parent->parent_link.'?section=templates&function=index',
			'save' => $this->parent->base_link.'&command=save',
			'create_group' => $this->parent->base_link.'&command=create_group',
			'change_group_position' => $this->parent->base_link.'&command=change_group_position',
			'create_question' => $this->parent->base_link.'&command=create_question',
			'create_question_confirm' => $this->parent->base_link.'&command=create_question_confirm',
			'edit_group' => $this->parent->base_link.'&command=edit_group',
			'change_question_position' => $this->parent->base_link.'&command=change_question_position',
			'edit_question' => $this->parent->base_link.'&command=edit_question',
			'template_metadata' => $this->parent->base_link.'&command=template_metadata'
		);

		$template = $this->parent->parent->getTemplate('admin_edit_template.php');
		$template->set_attribute('links', $links);
		$template->set_attribute('template', unserialize($_SESSION['template']));
		$template->set_attribute('db_answers', ibit_EvaluationAnswer::getAnswerInfos());
		echo $template->render();
	}

	/**
	 * Ldt eine Evaluationsvorlage aus der Datenbank in die Session.
	 * @param int $template_id Id der Evaluationsvorlage
	 * @uses ibit_EvaluationTemplate
	 */
	function load( $template_id )
	{
		$evaltemplate = new ibit_EvaluationTemplate($this->template_id);
		$evaltemplate->loadStructure();

		$edit_template = $evaltemplate->flattenToArray();

		$_SESSION['template'] = serialize($edit_template);

		StudIPTemplateEngine::showSuccessMessage('Die Vorlage wurde erfolgreich geladen');
	}


	/**
	 * Speichert die Werte der Evaluationsvorlage aus der Session in die Datenbank.
	 * Falls die Evaluationsvorlage gespeichert werden konnte, werden ihre Daten aus der Session gelscht.
	 * @uses ibit_EvaluationTemplate
	 * @uses ibit_EvaluationGroup
	 * @uses ibit_EvaluationQuestion
	 */
	function save()
	{
		// unserialize
		$template = unserialize($_SESSION['template']);
		// error flag
		$error = false;
		// check Title
		if (!strlen(trim($template['title'])))
		{
			StudIPTemplateEngine::showErrorMessage('Vorlagentitel ist zu kurz');
			$error = true;
		}
		// check status
		if ( (((integer)$template['status']) != 0) and (((integer)$template['status']) != 1) )
		{
			StudIPTemplateEngine::showErrorMessage('Falscher Status');
			$error = true;
		}

		# wenn error, fehler ausgeben
		if ($error)
		{
			$this->display();
			return;
		}

		if ( isset( $template['id'] ) )
		{
			$template_object = new ibit_EvaluationTemplate( $template['id'] );
		}
		else
		{
			$template_object = new ibit_EvaluationTemplate();
		}
		$template_object->setDescription($template['description']);
		$template_object->setTitle($template['title']);
		$template_object->setStatus($template['status']);
		$template_object->setAuthorId( $_SESSION['auth']->auth['uid'] );
		$template_object->setProtected( 0 );

		$template_object->groups = Array();

		$group_position = 1;
		foreach ($template['groups'] as $tpl_group)
		{
			if ( isset( $tpl_group['id'] ) )
			{
				$group = new ibit_EvaluationGroup( $tpl_group['id'] );
			}
			else
			{
				$group = new ibit_EvaluationGroup();
				$group->setProtected( 0 );
			}
			$group->setDescription( $tpl_group['description'] );
			$group->setTitle( $tpl_group['title'] );
			$group->setPosition( $group_position++ );

			$question_position = 1;
			foreach ($tpl_group['questions'] as $tpl_question)
			{
				if ( isset( $tpl_question['id'] ) )
				{
					$question = new ibit_EvaluationQuestion( $tpl_question['id'] );
				}
				else
				{
					$question = new ibit_EvaluationQuestion();
					$question->setProtected( 0 );
				}
				$question->setTitle( $tpl_question['title'] );
				$question->setText( $tpl_question['text']) ;
				$question->setAnswerTypeId( $tpl_question['answer_type_id'] );
				$question->setPosition( $question_position++ );

				$group->addQuestion( $question );
			}
			$template_object->addGroup( $group );
		}

		$template_object->save();
		$template_object->storeStructure();
		# Session lschen
		unset( $_SESSION['template'] );

		# Erfolgsmeldung ausgeben
		StudIPTemplateEngine::showSuccessMessage('Die Vorlage wurde erfolgreich gespeichert.');

		#Zurck zum bersichtsmen
		$this->parent->templates_index();
	}

	/**
	 * Aktualisiert die allgemeinen Daten einer Evaluationsvorlage in der Session.
	 */
	function metadata()
	{
		$template = unserialize($_SESSION['template']);

		if ( empty( $_POST['title'] ) or !isset( $_POST['status'] ) )
		{
			StudIPTemplateEngine::showErrorMessage('Bitte geben Sie zumindest einen Titel an');
			return;
		}

		$template['title'] = trim($_POST['title']);
		$template['status'] = trim($_POST['status']);
		$template['description'] = trim($_POST['description']);

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Daten wurden erfolgreich aktualisiert');
	}

	/**
	 * Legt eine neue Gruppe innerhalb der Evaluationsvorlage an.
	 */
	function create_group()
	{
		$template = unserialize($_SESSION['template']);

		if ( empty( $_REQUEST['title'] ) )
		{
			StudIPTemplateEngine::showErrorMessage('Bitte geben Sie einen Titel fr den Fragenblock an');
			return;
		}

		$group = Array();
		$group['title'] = trim($_REQUEST['title']);
		$group['description'] = trim($_REQUEST['description']);
		$group['questions'] = Array();

		array_push( $template['groups'], $group);

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Neue Gruppe <em>'.trim($_REQUEST['title']).'</em> wurde erfolgreich hinzugefgt');
	}

	/**
	 * Verschiebt eine Gruppe innerhalb der Evaluationsvorlage.
	 */
	function change_group_position()
	{
		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;
		$direction  = $_REQUEST['direction'];

		$group_count = count( $template['groups'] );
		if ( $group_count < 2 or ( $direction == 'down' and $group >= $group_count ) )
		{
			return;
		}

		$new_group = $direction == 'up' ? $group - 1 : $group + 1;

		$temp = $template['groups'][ $group ];
		$template['groups'][ $group ] = $template['groups'][ $new_group ];
		$template['groups'][ $new_group ] = $temp;

		$_SESSION['template'] = serialize($template);
	}

	/**
	 * Verschiebt eine Frage innerhalb ihrer Gruppe in der Evaluationsvorlage.
	 */
	function change_question_position()
	{
		$template = unserialize($_SESSION['template']);

		$group     = $_REQUEST['group']-1;
		$question  = $_REQUEST['question']-1;
		$direction = $_REQUEST['direction'];

		$question_count = count( $template['groups'][$group]['questions'] );
		if ( $question_count < 2 or ( $direction == 'down' and $question >= $question_count ) )
		{
			return;
		}

		$new_question = $direction == 'up' ? $question - 1 : $question + 1;

		$temp = $template['groups'][ $group ]['questions'][ $question ];
		$template['groups'][ $group ]['questions'][ $question ] = $template['groups'][ $group ]['questions'][$new_question ];
		$template['groups'][ $group ]['questions'][ $new_question ] = $temp;

		$_SESSION['template'] = serialize($template);
	}

	/**
	 * Lscht eine Gruppe aus der Evaluationsvorlage.
	 * @uses Iterator
	 */
	function delete_group()
	{
		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;
		$title = $template['groups'][ $group ]['title'];

		if ( md5( $title ) != $_REQUEST['hash'] )
		{
			StudIPTemplateEngine::showErrorMessage('Die Gruppe wurde nicht gelscht!<br/>Bitte versuchen Sie es erneut' );
			return;
		}

		// delete
		$iterator_groups = new Eval_Iterator( $template['groups'] );
		$iterator_groups->delete( $group );
		$template['groups'] = $iterator_groups->all();

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Fragenblock <em>'.$title.'</em> wurde erfolgreich gelscht');
	}

	/**
	 * Lscht eine Frage innerhalb einer Gruppe in der Evaluationsvorlage.
	 * @uses Iterator
	 */
	function delete_question()
	{
		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;
		$group_title = $template['groups'][ $group ]['title'];
		$question = $_REQUEST['question'] - 1;
		$question_title = $template['groups'][ $group ]['questions'][ $question ]['title'];
		$question_text = $template['groups'][ $group ]['questions'][ $question ]['text'];

		if ( md5( $question_text.$question_title ) != $_REQUEST['hash'] )
		{
			StudIPTemplateEngine::showErrorMessage('Die Frage wurde nicht gelscht!<br/>Bitte versuchen Sie es erneut');
			return;
		}

		$iterator_questions = new Eval_Iterator( $template['groups'][ $group ]['questions'] );
		$iterator_questions->delete( $question );
		$template['groups'][ $group ]['questions'] = $iterator_questions->all();

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Frage <em>'.$question_title.'</em> im Block <em>'.$group_title.'</em> wurde erfolgreich gelscht');
	}

	/**
	 * Left eine neue Frage innerhalb einer Gruppe in der Evaluationsvorlage an.
	 */
	function create_question()
	{
		echo 'foo';

		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;

		$question = array();
		$question['title'] = trim( $_REQUEST['question_title'] );
		$question['text'] = trim( $_REQUEST['question_text'] );
		$question['answer_type_id'] = trim( $_REQUEST['question_type_id'] );
		array_push( $template['groups'][ $group ]['questions'], $question );
		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Neue Frage "<em>'.trim($_REQUEST['question_title']).'</em>" wurde erfolgreich hinzugefgt');
	}

	/**
	 * Zeigt das Formular zum Bearbeiten der Werte einer Gruppe in der Evaluationsvorlage an.
	 */
	function edit_group()
	{
		$eval_template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;

		$template = $this->parent->parent->getTemplate('admin_edit_group.php');
		$template->set_attribute('link_cancel', $this->parent->base_link.'#group_title_'.($group+1));
		$template->set_attribute('link_save', $this->parent->base_link.'&command=edit_group_confirm&group='.($group+1).'#group_title_'.($group+1));
		$template->set_attribute('group', $eval_template['groups'][$group]);
		echo $template->render();
	}

	/**
	 * Speichert die nderungen an den Werten einer Gruppe in der Evaluationsvorlage in der Session.
	 * @uses Iterator
	 */
	function edit_group_confirm()
	{
		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;

		$iterator = new Eval_Iterator( $template['groups'] );
		$group_data = $iterator->at( $group );

		$group_data['title'] = trim($_REQUEST['title']);
		$group_data['description'] = trim($_REQUEST['description']);

		$iterator->replace( $group, $group_data );
		$template['groups'] = $iterator->all();

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Gruppendaten wurden erfolgreich angepasst');
	}

	/**
	 * Zeigt das Formular zum Bearbeiten der Werte einer Frage in der Evaluationsvorlage an.
	 */
	function edit_question()
	{
		$eval_template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;
		$question = $_REQUEST['question'] - 1;

		$template = $this->parent->parent->getTemplate('admin_edit_question.php');
		$template->set_attribute('link_cancel', $this->parent->base_link.'#group_title_'.($group+1));
		$template->set_attribute('link_save', $this->parent->base_link.'&command=edit_question_confirm&group='.($group+1).'&question='.($question+1).'#group_title_'.($group+1));
		$template->set_attribute('question', $eval_template['groups'][$group]['questions'][$question]);
		$template->set_attribute('db_answers', ibit_EvaluationAnswer::getAnswerInfos());
		echo $template->render();
	}

	/**
	 * Speichert die nderungen an den Werten einer Frage in der Evaluationsvorlage in der Session.
	 * @uses Iterator
	 */
	function edit_question_confirm()
	{
		$template = unserialize($_SESSION['template']);

		$group = $_REQUEST['group'] - 1;
		$question = $_REQUEST['question'] - 1;

		$question_data = Array();
		$question_data['text'] = trim($_REQUEST['text']);
		$question_data['title'] = trim($_REQUEST['title']);
		$question_data['answer_type_text'] = trim($_REQUEST['answer_type_text']);
		$question_data['answer_type_id'] = trim($_REQUEST['answers_type_id']);

		$iterator = new Eval_Iterator( $template['groups'][ $group ]['questions'] );
		$iterator->replace( $question, $question_data );
		$template['groups'][ $group ]['questions'] = $iterator->all();

		$_SESSION['template'] = serialize($template);

		StudIPTemplateEngine::showSuccessMessage('Angaben zur Frage wurden erfolgreich angepasst');
	}
}

?>