<?php
/**
 * classes/ibit_Action_Summary.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright IBIT 2006, 2007, 2008
 * @version 2.0.13
 */

/**
 * Diese Klasse enthlt alle Funktionen, um eine Evaluation auszuwerten und anzuzeigen.
 *
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @package    IBIT_Evaluation
 * @subpackage Action
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.3
 */
class ibit_Action_Summary
{
	/**
	 * Referenz auf das aufrufende Objekt
	 * @var object $parent
	 */
	var $parent;

	/**
	 * Erzeugter Link auf die Hauptseite des Plugins
	 * @var string $parent_link
	 */
	var $parent_link;

	/**
	 * Id der Evaluation
	 * @var string $evaluation_id
	 */
	 var $evaluation_id;

	/**
	 * ID des Benutzers
	 * @var string $user_id
	 */
	 var $user_id = null;

	/**
	 * Der Konstruktor der Klasse.
	 * @param object $parent Referenz auf das aufrufende Objekt
	 * @param string $evaluation_id Id der Evaluation
	 * @uses PluginEngine::getLink()
	 */
	function ibit_Action_Summary( $parent, $evaluation_id )
	{
		$this->parent = $parent;
		$this->evaluation_id = $evaluation_id;

		$this->parent_link = PluginEngine::getLink( $this->parent );

		# Prfen, ob der User die Rolle 'eval_admin' hat oder root ist
		$user = $this->parent->getUser();
		$permission	= $user->getPermission();
		$eval_admin = false;
		$roles = $user->getAssignedRoles();
		foreach ( $roles as $role )
		{
			if ( $role->rolename == 'eval_admin' )
			{
				$eval_admin = true;
			}
		}
		if ( $permission->hasAdminPermission() or $eval_admin )
		{
			$this->user_id = $user->userid;
		}
		#echo "<pre>"; print_r($_POST); echo "</pre>";
		if(!empty( $_POST['action'] ) && $_POST['action'] == 'change_charttype')
		{
			$this->changeChart();
		}

	}

	/**
	 * Zeigt die Auswertung der Evaluation an.
	 * @uses ibit_Evaluation::getAnswers()
	 * @todo Ergegbnisse laden und ans Template geben
	 */
	function show()
	{

		# Ergegbnisse laden und ans Template geben
		#$evaluation = new ibit_EvaluationSummary($this->evaluation_id, $this->user_id);
		//echo "<pre>"; print_r($evaluation); echo"</pre>";
		#$results = $evaluation->getAnswers();
		#$overview = $evaluation->getOverview();


		$summary = $this->fetch();

		if (!empty($_GET['print']) and $_GET['print']=='yes')
		{
			ob_end_clean();

			$header_template = $this->parent->getTemplate('print_header');
			$footer_template = $this->parent->getTemplate('print_footer');

			echo $header_template->render();
			echo $summary;
			echo $footer_template->render();

			ob_start();
		}
		else
		{
			echo $summary;
		}
	}

	/**
	 * Gibt die Auswertung der Evaluation zurck.
	 * @return string HTML-Code der Auswertung
	 * @uses ibit_EvaluationSummary
	 * @uses ibit_Evaluation::getAnswers()
	 */
	function fetch()
	{
		# Ergegbnisse laden und ans Template geben
		$evaluation = new ibit_EvaluationSummary($this->evaluation_id, $this->user_id);
		$results = $evaluation->getAnswers();
		$overview = $evaluation->getOverview();
		#echo "<pre>"; print_r($results); echo"</pre>";

		$template = $this->parent->getTemplate('common_display_summary');
		$template->set_attribute( 'overview', $overview );
		$template->set_attribute( 'results', $results );
		$template->set_attribute( 'link_request', $_SERVER['REQUEST_URI']);
		$template->set_attribute( 'image_type', ibit_EvaluationConfig::GetConfig('image', 'type'));
		return $template->render();
	}

	/**
	 * Speichert die nderung des Diagrammtyps (pie oder bar)
	 */
	function changeChart()
	{
		if(empty($_POST['user_id']))
		{
			ibit_EvaluationSummaryView::updateUserViewForQuestion( $_POST['evaluation_id'], $_POST['evaluation_group_template_id'], $_POST['evaluation_question_template_id'], $_POST['chart'] );
		}
		else
		{
			ibit_EvaluationSummaryView::updateAdminViewForQuestion( $_POST['evaluation_id'], $_POST['evaluation_group_template_id'], $_POST['evaluation_question_template_id'], $_POST['user_id'], $_POST['chart'] );
		}
		$this->parent->reportSuccess('Ihre nderung wurde erfolgreich gespeichert.' );
	}
}
?>