<?php
/**
 * classes/ibit_EvaluationAnswer.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.1
 */

/**
 * Die Reprsentation einer Evaluationsantwort.
 *
 * Diese Klasse stellt eine Reprsentation der Daten einer Antwort einer Evaluation dar.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@mail.uni-oldenburg.de>
 * @author     Ivn Marcos <ivan.marcos@gmx.net>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.1
 */
class ibit_EvaluationAnswer
{
	/**
	 * Die ID der Antwort
	 * @var string $evaluation_answer_template_id
	 */
	var $evaluation_answer_template_id = null;

  	/**
   	 * Der Text der Antwort
   	 * @var string $text
   	 */
  	var $text;

	/**
	  * Der Wert der Antwort
	  * @var string $value
	  */
	var $value;

	/**
	 * Der Status der Antwort
	 * @var int $status
	 */
	var $status;

	/**
	 * Gibt an, ob die aktuelle Antwort die Standardantwort ist
	 * @var boolean $default
	 */
	var $default;

	/**
	 * Die Position der Antwort
	 * @var int $position
	 */
	var $position;

	/**
	 * Konstruktor der Klasse.
	 * @param int $id Id der Evaluationsantwort
	 */
	function ibit_EvaluationAnswer( $id = null )
	{
		if ( $id !== null )
		{
			$this->load( $id );
		}
	}

	/**
	 * Ldt die Daten der Antwort mit der bergebenen Id in dieses Objekt.
	 * @param string $eval_answer_id Id der Evaluationsantwort
	 * @return boolean Gibt an, ob das Laden erfolgreich war oder nicht.
	 */
	function load( $eval_answer_template_id )
	{
		$this->evaluation_answer_template_id = $eval_answer_template_id;

		$data = DBManager::Get()->query("SELECT text, value, status, position, `default` FROM ibit_evaluation_answer_templates WHERE evaluation_answer_template_id = '{$eval_answer_template_id}'")->fetch(PDO::FETCH_ASSOC);

		if (!$data)
		{
			return false;
		}
		$this->text = $data['text'];
		$this->value = $data['value'];
		$this->status = $data['status'];
		$this->default = $data['default'];
		$this->position = $data['position'];

		return true;
	}

	/**
	 * Liefert die Id der Evaluationsantwort zurck.
	 * @return int Id der Evaluationsantwort
	 */
	function getEvaluationAnswerId()
	{
		return $this->evaluation_answer_template_id;
	}

	/**
	 * Liefert die Id der Evaluationsantwort zurck.
	 * @return int Id der Evaluationsantwort
	 */
	function getId()
	{
		return $this->getEvaluationAnswerId();
	}

	/**
	 * Liefert den Text der Evaluationsantwort zurck.
	 * @return string Text der Evaluationsantwort
	 */
	function getText()
	{
		return $this->text;
	}

	/**
	 * Liefert den Wert der Evaluationsantwort zurck.
	 * @return string Wert der Evaluationsantwort
	 */
	function getValue()
	{
		return $this->value;
	}

	/**
	 * Liefert den Status der Evaluationsantwort zurck.
	 * @return int Status der Evaluationsantwort
	 */
	function getStatus()
	{
		return $this->status;
	}

	/**
	 * Liefert zurck, ob diese Evaluationsantwort die Standardantwort ist.
	 * @return boolean Gibt an, ob diese Evaluationsantwort die Standardantwort ist
	 */
	function getDefault()
	{
		return $this->default;
	}

	/**
	 * Liefert die Position der Evaluationsantwort zurck.
	 * @return int Position der Evaluationsantwort
	 */
	function getPosition()
	{
		return $this->position;
	}

	/**
	 * Bricht die objektorientierte Struktur in ein Array auf.
	 * Die Rckgabe sieht dabei wie folgt aus:<br/>
	 * <pre>
	 *    [
	 *     id       => Id der Evaluationsantwort,
	 *     text     => Text der Evaluationsantwort,
	 *     value    => Wert der Evaluationsantwort,
	 *     status   => Status der Evaluationsantwort,
	 *     default  => Gibt an, ob die Evaluationsantwort eine Standardantwort ist,
	 *     position => Position der Evaluationsantwort
	 *    ]
	 * </pre>
	 *
	 * @return array Evaluationsantwortdaten
	 */
	function flattenToArray()
	{
		$result = array();

		$result['id'] = $this->evaluation_answer_template_id;
		$result['text'] = $this->text;
		$result['value'] = $this->value;
		$result['status'] = $this->status;
		$result['default'] = $this->default;
		$result['position'] = $this->position;

		return $result;
	}

##########################
## STATISCHE FUNKTIONEN ##
##########################

	/**
	 * Liest alle relevanten Infos ber die Antworttypen aus der DB.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *      id          => Id des Antworttyps,
	 *      title       => Titel des Antworttyps,
	 *      description => Beschreibung des Antworttyps
	 *    ]{0..x}
	 *
	 * @return array Evaluationsantworttypendaten
	 * @static
	 */
	function getAnswerInfos()
	{
		$rows = DBManager::Get()->query("SELECT evaluation_answer_type_id AS id, title, description FROM ibit_evaluation_answer_types ORDER BY evaluation_answer_type_id ASC")->fetchAll(PDO::FETCH_ASSOC);

		$answers = array();
		foreach ($rows as $row)
		{
			$answers[ $row['id'] ] = $row;
		}

		return $answers;
	}
}
?>