<?php
/**
 * classes/ibit_EvaluationSeminar.class.php
 *
 * @author  Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @author  Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author  Ivn Marcos <ivan.marcos@gmx.net>
 * @author  Nico Mueller <nico.mueller@uni-oldenburg.de>
 * @package IBIT_Evaluation
 * @copyright Copyright 2006, 2007 IBIT
 * @version 1.2
 */

/**
 * Diese Klasse kapselt die Zugriffe auf alle fr das Plugin ntige Daten eines Seminars.
 *
 * @author     Jan-Hendrik Willms <tleilax@mindfuck.de>
 * @author     Michael Riehemann <michael.riehemann@uni-oldenburg.de>
 * @package    IBIT_Evaluation
 * @subpackage Structure
 * @copyright  Copyright 2006, 2007 IBIT
 * @version    1.7
 */
class ibit_EvaluationSeminar
{
	/**
	 * Id des Seminars
	 * @var string $seminar_id
	 */
	var $seminar_id;

	/**
	 * Name des Seminars
	 * @var string $seminar_name
	 */
	var $seminar_name;

	/**
	 * Id des Instituts des Seminars
	 * @var string $institute_id
	 */
	var $institute_id;

	/**
	 * Name des Institut des Seminars
	 * @var string $institute_name
	 */
	var $institute_name;

	/**
	 * Id der Fakultt des Instituts des Seminars
	 * @var string $faculty_id
	 */
	var $fakultaet_id;

	/**
	 * Anzahl der Teilnehmer des Seminars
	 * @var int $members
	 */
	var $members;

	/**
	 * Namen der Dozenten
	 * @var array $teachers
	 */
	var $teachers;

	/**
	 * Der Konstruktor der Klasse.
	 * @param string $seminar_id Id des Seminars
	 */
	function ibit_EvaluationSeminar( $seminar_id )
	{
		$this->seminar_id = $seminar_id;
		$this->load();
	}

	/**
	 * Ldt die relevanten Daten des Seminars aus der Datenbank
	 * @return boolean Gibt an, ob das Laden erfolgreich war.
	 */
	function load()
	{
		$data = DBManager::Get()->query("SELECT s.Name AS seminar_name, s.Institut_id AS institute_id, i.Name as institute_name, i.fakultaets_id AS fakultaet_id FROM seminare AS s LEFT JOIN Institute AS i USING(Institut_id) WHERE s.seminar_id = '{$this->seminar_id}'")->fetch(PDO::FETCH_ASSOC);
		if ( !$data )
		{
			return false;
		}
		$this->seminar_name = $data['seminar_name'];
		$this->institute_name = $data['institute_name'];
		$this->institute_id = $data['institute_id'];
		$this->faculty_id = $data['fakultaet_id'];

		$this->teachers = DBManager::Get()->query("SELECT CONCAT( c.title_front, ' ', b.Vorname, ' ', b.Nachname ) AS name FROM ( seminar_user AS a LEFT JOIN auth_user_md5 AS b USING ( user_id ) ) LEFT JOIN user_info AS c USING ( user_id ) WHERE a.seminar_id = '{$this->seminar_id}' AND a.status = 'dozent'")->fetchAll(PDO::FETCH_COLUMN);

		$this->members = DBManager::Get()->query("SELECT COUNT(user_id) FROM seminar_user WHERE seminar_id = '{$this->seminar_id}' AND status NOT IN ('dozent', 'admin', 'tutor')")->fetchColumn();

		return true;
	}

	/**
	 * Liefert den Namen des Seminars zurck.
	 * @return string Name des Seminars
	 */
	function getName()
	{
		return $this->seminar_name;
	}

	/**
	 * Liefert die Anzahl der Teilnehmer an dem Seminar zurck.
	 * @return int Anzahl der Teilnehmer an dem Seminar
	 */
	function getMembers()
	{
		return $this->members;
	}

	/**
	 * Liefert dieNamen der Dozenten zurck
	 * @return array Dozenten
	 */
	function getTeachers()
	{
		return $this->teachers;
	}

	/**
	 * Bricht das Objekt in ein Array auf.
	 * Die Rckgabe sieht dabei folgendermassen aus:<br/>
	 * <pre>
	 *    [
	 *     seminar_id     => Id des Seminars,
	 *     seminar_name   => Name des Seminars,
	 *     institute_id   => Id des Instituts des Seminars,
	 *     institute_name => Name des Instituts des Seminars,
	 *     fakultaet_id   => Id der Fakultt des Seminars,
	 *     members        => Anzahl der Teilnehmer an dem Seminar
	 *    ]
	 * </pre>
	 *
	 * @return array Seminardaten
	 */
	function flattenToArray()
	{
		$result = Array();
		$result['seminar_id'] = $this->seminar_id;
		$result['seminar_name'] = $this->seminar_name;
		$result['institute_name'] = $this->institute_name;
		$result['institute_id'] = $this->institute_id;
		$result['fakultaet_id'] = $this->faculty_id;
		$result['members'] = $this->members;

		return $result;
	}

##########################
## STATISCHE FUNKTIONEN ##
##########################

	/**
	 * Liefert die aggregierten Teilnehmer an den Seminaren eines Instituts fr ein bestimmtes Semester zurck.
	 * @param string $institute_id Id des Instituts
	 * @param string $semester_id Id des Semesters
	 * @return int Anzahl der Teilnehmer an den Seminaren des Institutes in dem entsprechenden Semester
	 * @static
	 */
	function getSeminarMemberCountByInstituteId( $institute_id, $semester_id, $additional_where_clause = '' )
	{
		$seminars = DBManager::Get()->query("SELECT seminar_id FROM ibit_evaluation WHERE institut_id = '{$institute_id}' AND semester_id = '{$semester_id}' AND ".(empty($additional_where_clause)?'1':$additional_where_clause))->fetchAll(PDO::FETCH_COLUMN);
		
		return empty($seminars)
			? 0
			: DBManager::Get()->query("SELECT COUNT(user_id) FROM seminar_user WHERE seminar_id IN ('".implode("','", $seminars)."') AND status NOT IN ('dozent', 'admin', 'tutor')")->fetchColumn();
	}

	/**
	 * Liefert die aggregierten Teilnehmer an den Seminaren einer Fakultt fr ein bestimmtes Semester zurck.
	 * @param string $faculty_id Id der Fakultt
	 * @param string $semester_id Id des Semesters
	 * @return int Anzahl der Teilnehmer an den Seminaren des Institutes in dem entsprechenden Semester
	 * @static
	 */
	function getSeminarMemberCountByFacultyId( $faculty_id, $semester_id, $additional_where_clause = '' )
	{
		//TODO: schleife ber institute und dann schleife ber getSeminarMemberCountByInstituteId()
		return 0;
	}

	/**
	 * Ldt die relevanten Infos zu einer Menge von Seminaren.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     Seminar_id           => Id des Seminars,
	 *     Institut_id          => Id des Instituts des Seminars,
	 *     Fakultaets_id        => Id der Fakultt des Seminars,
	 *     Name                 => Name des Seminars,
	 *     VeranstaltungsNummer => Veranstaltungsnummer des Seminars,
	 *     Anzahl               => Anzahl der Teilnehmer an dem Seminar,
	 *     ects                 => ECTS-Punkte des Seminars
	 *    ]{0..x}
	 *
	 * @param array $seminar_ids Ids der Seminare
	 * @return array Seminardaten
	 * @static
	 */
	function getSeminarData( $seminar_ids )
	{
		# Seminar-Ids in das von StudIP benutzte gepaddete Format bringen
		foreach ( $seminar_ids as $idx=>$seminar_id )
		{
			$seminar_ids[$idx] = str_pad($seminar_id, 32, '0', STR_PAD_LEFT);
		}

		$seminar_data = DBManager::Get()->query("SELECT s.Seminar_id, s.Name, VeranstaltungsNummer, SUM( IF( u.status NOT IN ('dozent', 'tutor', 'admin'), 1, 0 ) ) AS Teilnehmer_Seminar, ects, IFNULL(i.fakultaets_id, 'k.A.') AS Fakultaet_id, s.Institut_id AS Institut_id, s.art AS Art FROM seminare AS s LEFT JOIN seminar_user AS u USING( Seminar_id ) LEFT JOIN seminar_inst AS si ON( s.Seminar_id=si.seminar_id) LEFT JOIN Institute AS i ON (s.Institut_id=i.Institut_id OR si.institut_id=i.institut_id) WHERE s.Seminar_id IN ('".implode("','", array_unique((array)$seminar_ids))."') AND fakultaets_id IS NOT NULL GROUP BY s.Seminar_id")->fetchAll(PDO::FETCH_ASSOC);

		$seminars = array();
		foreach ($seminar_data as $seminar)
		{
			$seminars[ $seminar['Seminar_id'] ] = $seminar;
		}

		return $seminars;
	}

	/**
	 * Sucht ein Seminar anhand eines Teils des Namens, Veranstaltungsnummer und eines gegebenen Semesters.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     Seminar_id           => Id des Seminars,
	 *     Institut_id          => Id des Instituts des Seminars,
	 *     Fakultaets_id        => Id der Fakultt des Seminars,
	 *     Name                 => Name des Seminars,
	 *     VeranstaltungsNummer => Veranstaltungsnummer des Seminars,
	 *     Anzahl               => Anzahl der Teilnehmer an dem Seminar,
	 *     ects                 => ECTS-Punkte des Seminars
	 *    ]{0..x}
	 *
	 * @param string $name Teil des Namens, nach dem gesucht werden soll
	 * @param string $number Teil der Veranstaltungsnummer
	 * @param string $semester_id Id des Semesters
	 * @return array Seminardaten
	 * @static
	 */
	function searchSeminarByNameAndSemester( $name, $number, $semester_id )
	{
		$sql_search_seminars = "SELECT s.Seminar_id, s.Name, VeranstaltungsNummer, SUM( IF( u.status NOT IN ('dozent', 'tutor', 'admin'), 1, 0 ) ) AS Teilnehmer_Seminar, ects, IFNULL(i.fakultaets_id, 'k.A.') AS Fakultaet_id, s.Institut_id AS Institut_id, i.Name AS Institut_Name FROM seminare AS s LEFT JOIN seminar_user AS u USING( Seminar_id ) LEFT JOIN seminar_inst AS si ON(s.Seminar_id=si.seminar_id) LEFT JOIN Institute AS i ON (s.Institut_id=i.Institut_id OR si.institut_id=i.institut_id) INNER JOIN semester_data AS sem ON (sem.semester_id='{$semester_id}') WHERE ##searchcriteria## AND start_time BETWEEN sem.beginn AND sem.ende AND fakultaets_id IS NOT NULL GROUP BY s.Seminar_id";

		$search_criteria = array();
		if ( !empty( $name ) )
		{
			array_push( $search_criteria, "s.Name LIKE '%".$name."%'" );
		}
		if ( !empty( $number ) )
		{
			array_push( $search_criteria, "s.VeranstaltungsNummer LIKE '%".$number."%'" );
		}
		if ( empty( $search_criteria ) )
		{
			return array();
		}
		$sql_search_seminars = str_replace( '##searchcriteria##', implode(' AND ', $search_criteria), $sql_search_seminars);

		#echo $sql_search_seminars;
		$seminar_data = DBManager::Get()->query($sql_search_seminars)->fetchAll(PDO::FETCH_ASSOC);

		$seminars = array();
		foreach ($seminar_data as $seminar)
		{
			$seminars[ $seminar['Seminar_id'] ]	= $seminar;
		}

		return $seminars;
	}

	function searchSeminarByNameAndDozent( $veranstaltung, $dozent )
	{
		$sql_search_seminars = "SELECT s.Seminar_id, s.Name, u.Vorname, u.Nachname, u.username, c.name AS Semester FROM seminare AS s LEFT JOIN seminar_user AS b USING ( Seminar_id ) LEFT JOIN auth_user_md5 AS u USING ( user_id ) LEFT JOIN semester_data AS c ON c.beginn = s.start_time INNER JOIN ibit_evaluation AS d on d.seminar_id = s.Seminar_id WHERE b.status = 'dozent' ##searchcriteria## GROUP BY s.Seminar_id ORDER BY c.semester_id DESC";

		$search_criteria = '';
		if ( !empty( $veranstaltung ) )
		{
			$search_criteria .= " AND s.Name LIKE '%".$veranstaltung."%'";
		}
		if ( !empty( $dozent ) )
		{
			$search_criteria .=" AND ( u.Vorname LIKE '%".$dozent."%' OR u.Nachname LIKE '%".$dozent."%' )";
		}

		$sql_search_seminars = str_replace( '##searchcriteria##', $search_criteria, $sql_search_seminars);
		#echo $sql_search_seminars;

		$seminar_data = DBManager::Get()->query($sql_search_seminars)->fetchAll(PDO::FETCH_ASSOC);

		$seminars = array();
		foreach ($seminar_data as $seminar)
		{
			$seminars[ $seminar['Seminar_id'] ] = $seminar;
		}

		return $seminars;
	}

	/**
	 * Liefert alle IDs von Tutoren zu einer Veranstaltung zurck
	 *
	 * @param string $seminar_id Ids des Seminares
	 * @return array IDs der Tutoren
	 * @static
	 */
	function getTutorsForSeminar($seminar_id)
	{
		return DBManager::Get()->query("SELECT user_id FROM seminar_user WHERE Seminar_id = '{$seminar_id}' AND status='tutor'")->fetchAll(PDO::FETCH_COLUMN);
	}

	/**
	 * Liest die relevanten Dozentendaten einer Menge von Seminaren aus.
	 * Die Rckgabe sieht dabei folgendermassen aus:
	 *    [
	 *     user_id    => User-Id des Dozenten,
	 *     Vorname    => Vorname des Dozenten,
	 *     Nachname   => Nachname des Dozenten,
	 *     seminar_id => Id des Seminars
	 *    ]{0..x}
	 *
	 * @param array $seminar_ids Ids der Seminare
	 * @return array Dozentendaten
	 * @static
	 */
	function getDozentDataForSeminar( $seminar_ids )
	{
		return DBManager::Get()->query("SELECT s.Seminar_id AS seminar_id, s.user_id, Vorname, Nachname FROM seminar_user AS s LEFT JOIN auth_user_md5 AS u USING( user_id ) WHERE s.Seminar_id IN ('".implode("','", array_unique((array)$seminar_ids))."') AND s.status='dozent'")->fetchAll(PDO::FETCH_ASSOC);
	}
}
?>